@@ -82,8 +82,7 @@ class Context:
                 fut = await self.waitlist.get()
                 fut.set_result(None)
             self.locked = False
-            if self.task is not None:
-                self.task = None
+            self.task = None
 
     def _solve_code(self, raw_code: str) -> T_Executor:
         assert self.locked, "`Context._solve_code` must be called with lock"
@@ -102,6 +101,7 @@ class Context:
 
     @classmethod
     async def execute(cls, bot: Bot, session: Session, code: str) -> None:
+        uin = cls._session2uin(session)
         self = cls.get_context(session)
         API = get_api_class(bot)
 
@@ -109,10 +109,11 @@ class Context:
         async with self._lock():
             API(bot, session).export_to(self.ctx)
             executor = self._solve_code(code)
+            logger.debug(f"为用户 <y>{uin}</y> 创建 executor: {executor}")
             self.task = get_event_loop().create_task(executor())
             result, self.task = await self.task, None
 
-            if buf := Buffer.get(self._session2uin(session)).read().rstrip("\n"):
+            if buf := Buffer.get(uin).read().rstrip("\n"):
                 await UniMessage.text(buf).send()
             if result is not None:
                 await UniMessage.text(repr(result)).send()
